c ######################################################################
c #
c #                  AISI 304 SS PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of AISI 304 Stainless Steel
c #
c ######################################################################

c ######################################################################
      real function dAISI304(T)
c ######################################################################
c #
c # Density of AISI 304 Stainless Steel
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # Cryocomp v3.0
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dAISI304          x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dAISI304 = 7900.0
c *

      return
      end
c ######################################################################
      real function cAISI304(T)
c ######################################################################
c #
c # Specific heat of AISI 304 Stainless Steel
c #
c # Range: 1 <= T <= 1253 K
c #
c #                        References
c #                        ----------
c # Cryocomp v3.0
c # J.C.Ho, G.B.King, F.R.Fickett, Low Temperature Specific Heat of Two 
c # SS's, Cryogenics, 296-297, 1978
c # J.M.Corsan, N.I.Mitchen, The Specific Heat of SS between 4 K and 
c # 300 K, Proc. 6th Int. Cryo Eng. Conf, Grenoble, 342
c # Handbook on Materials for S.C. Machinery, NBS Boulder (yellow book), 
c # 1977
c # http://cryogenics.nist.gov/MPropsMAY/304Stainless/304Stainless_rev.htm
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cAISI304          x    specific heat                     J/Kg K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0
      real     A1,A2,A3
      real     AA,BB,CC,DD,a,b,c,d,na,nb,nc,nd
      real     Tmin,Tmax
      data     A1  / 0.464373874  / ,  A2  / 0.0         / ,
     &         A3  / 0.000351572 /
      data     AA  /-8142.325034  / ,  BB  / 0.0         / ,
     &         CC  / 3538.990183  / ,  DD  / 318.1578143 / 
      data     a   / 229.6339818  / ,  b   / 1.0         / ,
     &         c   / 45.73789754  / ,  d   / 2.336719622 / 
      data     na  / 1.075830718  / ,  nb  / 1.0         / ,
     &         nc  / 2.980530559  / ,  nd  / 3.842489398 / 
      data     T0  / 14.76238185  /
      data     Tmin / 1.0/, Tmax / 1253.0/
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      if(TT.le.T0) then

         cAISI304 = A1*T + A2*T**2 + A3*TT**3

      else
      
         cAISI304 = AA*TT   /(a+TT)**na + BB*TT**2/(b+TT)**nb + 
     &              CC*TT**3/(c+TT)**nc + DD*TT**4/(d+TT)**nd       

      endif

c *
      return
      end
c ######################################################################
      real function kAISI304(T)
c ######################################################################
c #
c # Thermal conductivity of AISI 304 Stainless Steel
c #
c # Range: 0.1 <= T <= 1672 K
c #
c #                        References
c #                        ----------
c # Cryocomp v3.0
c # Handbook on Materials for S.C. Machinery, NBS Boulder (yellow book), 
c # 1977
c # http://cryogenics.nist.gov/MPropsMAY/304Stainless/304Stainless_rev.htm
c # C.T.Ho, T.K. Chu, Electrical resistivity and thermal conductivity of 
c # nine selected AISI stainless steels, CINDAS Report 45, 1977
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kAISI304          x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     AA,BB,CC,DD,a,b,c,d,na,nb,nc,nd
      real     Tmin,Tmax
      data     AA  / 0.0          / ,  BB  / 0.0          / ,
     &         CC  / 137.0387356  / ,  DD  / 0.079634944  / 
      data     a   / 1.0          / ,  b   / 1.0          / ,
     &         c   / 34.47984497  / ,  d   / 0.228019354  / 
      data     na  / 1.0          / ,  nb  / 1.0          / ,
     &         nc  / 3.444155848  / ,  nd  / 3.202392383  / 
      data     Tmin / 0.1/, Tmax / 1672.0/
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      kAISI304 = AA*TT   /(a+TT)**na + BB*TT**2/(b+TT)**nb + 
     &              CC*TT**3/(c+TT)**nc + DD*TT**4/(d+TT)**nd       



c *
      return
      end
c ######################################################################
      real function rAISI304(T)
c ######################################################################
c #
c # Electrical resistivity of AISI 304 Stainless Steel
c #
c # Range: 0 <= T <= 1143 K
c #
c #                        References
c #                        ----------
c # Cryocomp v3.0
c # Handbook on Materials for S.C. Machinery, NBS Boulder (yellow book), 
c # 1977
c # C.T.Ho, T.K. Chu, Electrical resistivity and thermal conductivity of 
c # nine selected AISI stainless steels, CINDAS Report 45, 1977
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rAISI304          x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     A,B,nb
      real     Tmin,Tmax
      data     A   / 4.758914416 / ,  B  / 0.009900296 / ,
     &         nb  / 0.95536676 /
      data     Tmin   / 0.0/, Tmax   / 1143.0/
      save
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      rAISI304 = 1.0e-7 * (A + B*TT**nb)
	
c *
      return
      end
